@@ -2,12 +2,16 @@ from clusteval.clusteval import clusteval
 
 from clusteval.clusteval import (
     import_example,
+    dbindex,
+    silhouette,
+    derivative,
+    dbscan,
     )
 
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '2.0.5'
+__version__ = '2.1.1'
 
 
 __doc__ = """
